@@ -626,9 +626,16 @@ class BaseExperiment:
             y_test_predict_proba = y_test_predict_proba[:,1]
 
         if self.n_classes:
-            train_auc = roc_auc_score(y_true=self.y_train, y_score=y_train_predict_proba)
-            val_auc = roc_auc_score(y_true=self.y_val, y_score=y_val_predict_proba)   
-            test_auc = roc_auc_score(y_true=self.y_test, y_score=y_test_predict_proba)
+            train_auc, val_auc, test_auc = math.nan
+            
+            if self.n_classes == 2:
+                train_auc = roc_auc_score(y_true=self.y_train, y_score=y_train_predict_proba)
+                val_auc = roc_auc_score(y_true=self.y_val, y_score=y_val_predict_proba)   
+                test_auc = roc_auc_score(y_true=self.y_test, y_score=y_test_predict_proba)
+            else:
+                train_auc = roc_auc_score(y_true=self.y_train, y_score=y_train_predict_proba, multi_class='ovo')
+                val_auc = roc_auc_score(y_true=self.y_val, y_score=y_val_predict_proba, multi_class='ovo')   
+                test_auc = roc_auc_score(y_true=self.y_test, y_score=y_test_predict_proba, multi_class='ovo')
             self.logger.add_scalar('val/acc', val_acc)
             self.logger.add_scalar('train/acc', train_acc)
             self.logger.add_scalar('test/acc', test_acc)
